@@ -100,10 +100,6 @@ final class ArrayVarHandle extends VarHandle {
 		super(arrayType.getComponentType(), new Class<?>[] {arrayType, int.class}, populateMHs(arrayType), 0);
 	}
 
-	public MethodType accessModeTypeUncached(AccessMode accessMode) {
-		throw OpenJDKCompileStub.OpenJDKCompileStubThrowError();
-	}
-
 	/**
 	 * Type specific methods used by array element VarHandle methods.
 	 */
